Generate n random matrices, distributed according
to the inverse Wishart distribution with parameters Sigma and
df, \(W_p(Sigma, df)\).
Note there are different ways of parameterizing the Inverse
Wishart distribution, so check which one you need.
Here, if \(X \sim IW_p(\Sigma, \nu)\) then
\(X^{-1} \sim W_p(\Sigma^{-1}, \nu)\).
Dawid (1981) has a different definition: if
\(X \sim W_p(\Sigma^{-1}, \nu)\) and
\(\nu > p - 1\), then
\(X^{-1} = Y \sim IW(\Sigma, \delta)\),
where \(\delta = \nu - p + 1\).